@@ -11,7 +11,7 @@ use std::time::Duration;
 use submap::{BroadcastMap, SubMap};
 use tokio::io::{AsyncReadExt, AsyncWriteExt, BufReader, BufWriter};
 use tokio::net::{TcpListener, TcpStream, UnixListener, UnixStream};
-#[cfg(feature = "broker-api")]
+#[cfg(feature = "rpc")]
 use tokio::sync::Mutex;
 use tokio::task::JoinHandle;
 use tokio::time;
@@ -29,8 +29,10 @@ use crate::client::AsyncClient;
 use crate::{EventChannel, OpConfirm};
 use crate::{Frame, FrameData, FrameKind, FrameOp, QoS};
 
+#[cfg(feature = "rpc")]
+use crate::rpc::{Rpc, RpcClient};
 #[cfg(feature = "broker-api")]
-use crate::rpc::{Rpc, RpcClient, RpcError, RpcEvent, RpcHandlers, RpcResult};
+use crate::rpc::{RpcError, RpcEvent, RpcHandlers, RpcResult};
 
 use async_trait::async_trait;
 
@@ -38,6 +40,7 @@ pub const DEFAULT_QUEUE_SIZE: usize = 8192;
 
 pub const BROKER_INFO_TOPIC: &str = ".broker/info";
 pub const BROKER_WARN_TOPIC: &str = ".broker/warn";
+pub const BROKER_NAME: &str = ".broker";
 
 macro_rules! pretty_error {
     ($name: expr, $err:expr) => {
@@ -419,7 +422,7 @@ pub struct Broker {
     db: Arc<BrokerDb>,
     services: Vec<JoinHandle<()>>,
     queue_size: usize,
-    #[cfg(feature = "broker-api")]
+    #[cfg(feature = "rpc")]
     rpc_client: Option<Arc<Mutex<RpcClient>>>,
 }
 
@@ -579,7 +582,7 @@ impl Broker {
             db: broker_db,
             services: <_>::default(),
             queue_size: 0,
-            #[cfg(feature = "broker-api")]
+            #[cfg(feature = "rpc")]
             rpc_client: None,
         };
         // avoid warning if rpc feature is not set
@@ -587,7 +590,7 @@ impl Broker {
         #[cfg(feature = "broker-api")]
         {
             let client = broker
-                .register_client(".broker")
+                .register_client(BROKER_NAME)
                 .expect("can not register broker RPC");
             let handlers = BrokerRpcHandlers { db: broker_db };
             let rpc_client = RpcClient::new(client, handlers);
@@ -598,6 +601,10 @@ impl Broker {
     pub fn set_queue_size(&mut self, queue_size: usize) {
         self.queue_size = queue_size;
     }
+    #[cfg(feature = "rpc")]
+    pub fn set_core_rpc_client(&mut self, client: Arc<Mutex<RpcClient>>) {
+        self.rpc_client.replace(client);
+    }
     pub fn register_client(&self, name: &str) -> Result<Client, Error> {
         let (c, rx) =
             ElbusClient::new(name, self.queue_size, ElbusClientType::Internal, None, None);
@@ -609,6 +616,10 @@ impl Broker {
             rx: Some(rx),
         })
     }
+    #[inline]
+    pub fn unregister_client(&self, client: &Client) {
+        self.db.unregister_client(&client.client);
+    }
     pub async fn spawn_unix_server(
         &mut self,
         path: &str,
@@ -649,12 +660,22 @@ impl Broker {
         Ok(())
     }
     #[allow(clippy::items_after_statements)]
-    #[cfg(feature = "broker-api")]
+    /// Broker fifo channel is useful for shell scripts and allows to send:
+    ///
+    /// echo TARGET MESSAGE > /path/to/fifo # a one-to-one or broadcast message
+    /// echo '=TOPIC' MESSAGE # publish to a topic
+    /// echo TARGET .MESSAGE # RPC notification
+    /// echo TARGET :method param=value param=value # RPC call, the payload will be sent as msgpack
+    ///
+    /// Requires either broker-api feature or rpc feature + broker core rpc client to be set
+    #[cfg(feature = "rpc")]
     pub async fn spawn_fifo(&mut self, path: &str, buf_size: usize) -> Result<(), Error> {
         let rpc_client = if let Some(ref c) = self.rpc_client {
             c.clone()
         } else {
-            return Err(Error::not_supported("broker RPC not initialized"));
+            return Err(Error::not_supported(
+                "broker core RPC client not initialized",
+            ));
         };
         let _r = tokio::fs::remove_file(path).await;
         unix_named_pipe::create(path, Some(0o622))?;
@@ -687,7 +708,7 @@ impl Broker {
         self.services.push(service);
         Ok(())
     }
-    #[cfg(feature = "broker-api")]
+    #[cfg(feature = "rpc")]
     async fn send_fifo_cmd(rpc: &Arc<Mutex<RpcClient>>, line: String) -> Result<(), Error> {
         let cmd = line.trim();
         // topic
